#region Using directives

using System;
using System.Drawing;
using System.Collections;
using System.Windows.Forms;
using System.Data;
using Berkeley.CS160.ExperienceLogger;
using Berkeley.CS160.ExperienceLogger.Contexts;
using Berkeley.CS160.ExperienceLogger.Questions;
#endregion

namespace ESMTestApplication
{
    /// <summary>
    /// Summary description for form.
    /// </summary>
    public class Form1 : System.Windows.Forms.Form
    {
        private MenuItem menuItem1;
        private MenuItem menuItem2;
        private MenuItem menuItem3;
        private MenuItem menuItem4;
        private MenuItem menuItem5;
        private Label label1;

        private Logger m_logger;
        private Session m_session;
        private ResponseTimeContext m_responseTimeContext;

        /// <summary>
        /// Main menu for the form.
        /// </summary>
        private System.Windows.Forms.MainMenu mainMenu1;

        public Form1()
        {
            InitializeComponent();
            InitializeLogger();
        }

        /// <summary>
        /// Clean up any resources being used.
        /// </summary>
        protected override void Dispose(bool disposing)
        {
            base.Dispose(disposing);
        }

        #region Windows Form Designer generated code
        /// <summary>
        /// Required method for Designer support - do not modify
        /// the contents of this method with the code editor.
        /// </summary>
        private void InitializeComponent()
        {
            this.mainMenu1 = new System.Windows.Forms.MainMenu();
            this.menuItem1 = new System.Windows.Forms.MenuItem();
            this.menuItem2 = new System.Windows.Forms.MenuItem();
            this.menuItem3 = new System.Windows.Forms.MenuItem();
            this.menuItem4 = new System.Windows.Forms.MenuItem();
            this.menuItem5 = new System.Windows.Forms.MenuItem();
            this.label1 = new System.Windows.Forms.Label();
            // 
            // mainMenu1
            // 
            this.mainMenu1.MenuItems.Add(this.menuItem1);
            this.mainMenu1.MenuItems.Add(this.menuItem2);
            // 
            // menuItem1
            // 
            this.menuItem1.Text = "Quit";
            this.menuItem1.Click += new System.EventHandler(this.menuItem1_Click);
            // 
            // menuItem2
            // 
            this.menuItem2.MenuItems.Add(this.menuItem3);
            this.menuItem2.MenuItems.Add(this.menuItem4);
            this.menuItem2.MenuItems.Add(this.menuItem5);
            this.menuItem2.Text = "Main Menu";
            // 
            // menuItem3
            // 
            this.menuItem3.Text = "Question set 1";
            this.menuItem3.Click += new System.EventHandler(this.menuItem3_Click);
            // 
            // menuItem4
            // 
            this.menuItem4.Text = "Picture prompt";
            this.menuItem4.Click += new System.EventHandler(this.menuItem4_Click);
            // 
            // menuItem5
            // 
            this.menuItem5.Text = "Vibrate test";
            this.menuItem5.Click += new System.EventHandler(this.menuItem5_Click);
            // 
            // label1
            // 
            this.label1.Font = new System.Drawing.Font("Segoe Condensed", 11F, System.Drawing.FontStyle.Regular);
            this.label1.Location = new System.Drawing.Point(3, 0);
            this.label1.Size = new System.Drawing.Size(237, 187);
            this.label1.Text = "This application demonstrates the functionality of the Experience Logger toolkit." +
                "  Select \"Main Menu\" to begin.\r\n\r\nOutput will be written to temp.xml in the root" +
                " directory of this device.";
            // 
            // Form1
            // 
            this.ClientSize = new System.Drawing.Size(240, 266);
            this.Controls.Add(this.label1);
            this.Menu = this.mainMenu1;
            this.Text = "Experience Logger Test";

        }

        #endregion

        /// <summary>
        /// The main entry point for the application.
        /// </summary>
        static void Main()
        {
            Application.Run(new Form1());
        }

        /// <summary>
        /// This function includes code that initializes the logger, creates three questions, and starts a logging session
        /// </summary>
        private void InitializeLogger()
        {
            m_logger = new Logger();

            m_logger.RegisterQuestion(new SelectAnyMultipleChoiceQuestion("test_question", "This is a question?", new string[] { "Yes", "No" }));
            m_logger.RegisterQuestion(new SelectOneMultipleChoiceQuestion("test_question2", "How much did you like the previous question?", new string[] { "Not at all", "Unclear", "Somewhat", "A whole lot!" }));
            m_logger.RegisterQuestion(new ImageCaptureQuestion("image_capture_test", "Take a picture..."));

            m_session = m_logger.CreateSession("Test Session");

            // Start timing how long it takes the user to select "Question set 1" from the menu
            m_responseTimeContext = new ResponseTimeContext("time_elapsed");
            m_responseTimeContext.StartTimer();
        }

        /// <summary>
        /// Function called when the "Question set 1" menu option is selected
        /// </summary>
        private void menuItem3_Click(object sender, EventArgs e)
        {
            // Stop the response time timer
            m_responseTimeContext.StopTimer();
            
            // Ask the first question, and store the response time context
            // (e.g., the time until this question was asked)
            // The context could also be written separately to the log as 
            // m_session.WriteContext("time_to_pick_question_set_1");
            m_session.AskQuestion("test_question", m_responseTimeContext);
            
            // Ask the second question
            m_session.AskQuestion("test_question2");
        }

        /// <summary>
        /// Function called when the Picture Prompt menu option is selected
        /// (Not tested on an actual phone yet.)
        /// </summary>
        private void menuItem4_Click(object sender, EventArgs e)
        {
            m_session.AskQuestion("image_capture_test");
        }

        /// <summary>
        /// Function called when the Vibrate test menu option is selected
        /// (Not tested on an actual phone yet.)
        /// </summary>
        private void menuItem5_Click(object sender, EventArgs e)
        {
            bool result = PhoneUtilities.Vibrate(TimeSpan.FromSeconds(5));
        }

        /// <summary>
        /// Function called when the "Exit" menu option is selected
        /// </summary>
        private void menuItem1_Click(object sender, EventArgs e)
        {
            // Save the current logger state
            m_logger.Save("temp.xml");
        
            Application.Exit();
        }
    }
}

