using System;
using System.Collections;
using System.Text;
using System.Xml;

namespace Berkeley.CS160.ExperienceLogger.Contexts
{
    public class ResponseTimeContext : ADefaultContext
    {
        DateTime m_startTime;
        DateTime m_stopTime;
        bool m_timing = false;
        bool m_timed = false;

        public ResponseTimeContext(string name) : base("response_time", name) { }
        public ResponseTimeContext() : this(null) { }

        public void StartTimer()
        {
            if (m_timing)
            {
                throw new Exception("Already running the timer.");
            }
            m_timing = true;
            m_startTime = DateTime.Now;
        }

        public void StopTimer()
        {
            if (!m_timing)
            {
                throw new Exception("Timer hasn't been started yet.");
            }
            m_stopTime = DateTime.Now;
            m_timing = false;
            m_timed = true;
        }

        public override XmlNode CreateDescription(Logger logger)
        {
            if (!m_timed)
            {
                throw new Exception("Must run the timer before logging it");
            }

            XmlNode node = CreateDefaultDescription(logger);
            XmlAttribute startAtt = logger.CreateAttribute("start_time");
            startAtt.Value = m_startTime.ToLongTimeString();

            XmlAttribute stopAtt = logger.CreateAttribute("stop_time");
            stopAtt.Value = m_stopTime.ToLongTimeString();

            XmlAttribute durationAtt = logger.CreateAttribute("duration_ms");
            durationAtt.Value = ((TimeSpan)(m_stopTime - m_startTime)).TotalMilliseconds.ToString();

            node.Attributes.Append(startAtt);
            node.Attributes.Append(stopAtt);
            node.Attributes.Append(durationAtt);

            return node;
        }
    }
}
