using System;
using System.Collections;
using System.Text;
using System.Xml;
using System.Windows.Forms;

using Berkeley.CS160.ExperienceLogger.Questions;
using Berkeley.CS160.ExperienceLogger.Contexts;

namespace Berkeley.CS160.ExperienceLogger
{
    public class Session
    {
        private XmlNode m_loggerNode;
        private Logger m_logger;

        public Session(XmlNode loggerNode, Logger logger)
        {
            m_loggerNode = loggerNode;
            m_logger = logger;
        }

        public void WriteContext(string instanceName, IContext context)
        {
            m_loggerNode.AppendChild(CreateEntry(instanceName, null, context));
        }

        public void AskQuestion(string questionName)
        {
            AskQuestion(questionName, null, null);
        }

        public void AskQuestion(string questionName, string instanceName)
        {
            AskQuestion(questionName, instanceName, null);
        }

        public void AskQuestion(string questionName, IContext context)
        {
            AskQuestion(questionName, null, context);
        }

        public void AskQuestion(string questionName, string instanceName, IContext context)
        {
            if (!m_logger.Questions.Contains(questionName))
            {
                throw new ArgumentException("Question " + questionName + " not registered.");
            }
            else
            {
                AQuestion question = (AQuestion)m_logger.Questions[questionName];
                AQuestionInstance instance = question.CreateInstance();
                DialogResult result = instance.ShowControl();
                if (result == DialogResult.OK)
                {
                    XmlNode response = CreateEntry(instanceName, instance, context);
                    m_loggerNode.AppendChild(response);
                }
            }
        }

        /// <summary>
        /// Add Context Here Later
        /// </summary>
        /// <param name="name"></param>
        /// <param name="question"></param>
        /// <returns></returns>
        private XmlNode CreateEntry(string name, AQuestionInstance question, IContext context)
        {
            XmlNode node = m_logger.CreateElement("Entry");
            XmlAttribute nameAtt = m_logger.CreateAttribute("name");
            nameAtt.Value = name;
            node.Attributes.Append(nameAtt);

            if (context != null)
            {
                node.AppendChild(context.CreateDescription(m_logger));
            }

            if (question != null)
            {
                node.AppendChild(question.GetResponse(m_logger));
            }

            return node;
        }
    }
}
